@@ -1731,10 +1731,10 @@ class Update(MethodsInterface):
         #had to extract ignore level logic to cl_update because of variable module
         ignore_level = not cl_check_update_level
         # ignore_level = self.clVars.Get('cl_check_update_level') == Variable.Off
-        current_level_is_valid = self.check_current_level() if not ignore_level else None
+        current_level_is_valid = self.check_current_level() if not ignore_level else False
         self.startTask(_("Searching new binhost"))
         retval = self._search_best_binhost(self.binhosts_data,
-                 stabilization, ignore_level)
+                 stabilization, ignore_level or not current_level_is_valid)
 
         
         self.clVars.Set('update.cl_update_binhost_data',
